float4x4 WorldViewProjection : WORLDVIEWPROJECTION;
float4x4 World : WORLD;
float4 Kolor : COLOR = float4(1.0,1.0,0.0,1.0);
bool UzyjKoloruWerteksu = true;
bool PreferujPerPixel = true;
float Czas : TIME = 0;
bool TeksturowanieWlaczone = false;
bool UzyjMapyRozblysku = true;

//zrodlo swiatla
float4 Ca : COLOR = float4(0.1,0.1,0.1,1);
float4 Cd : COLOR = float4(0.5,0.5,0.5,1);
float4 Cs : COLOR = float4(1,1,1,1);
float3 PozycjaZrodlaSwiatla = float3(3,3,3);
float3 KierunekDoKamery = float3(0,0,1);

//material
float4 Wa : COLOR = float4(1,1,1,1);
float4 Wd : COLOR = float4(1,1,1,1);
float4 Ws : COLOR = float4(1,1,1,1);
float ns = 10;

//teksturowanie
texture2D Tekstura;
sampler2D Probnik = sampler_state
{
	texture = <Tekstura>;
	magfilter = LINEAR;
	minfilter = LINEAR;
	mipfilter = LINEAR;
	addressU = CLAMP;
	addressV = CLAMP;
};

//mieszanie tekstur
texture2D Tekstura2;
sampler2D Probnik2 = sampler_state
{
	texture = <Tekstura2>;
	magfilter = LINEAR;
	minfilter = LINEAR;
	mipfilter = LINEAR;
	addressU = CLAMP;
	addressV = CLAMP;
};

//specular map
texture2D SpecularMap;
sampler2D ProbnikMapyRozblysku = sampler_state
{
	texture = <SpecularMap>;
	magfilter = LINEAR;
	minfilter = LINEAR;
	mipfilter = LINEAR;
	addressU = CLAMP;
	addressV = CLAMP;
};

struct Dane_Wejsciowe_VS
{
	float4 Pozycja : POSITION0;
	float4 Kolor : COLOR0;
	float3 Normalna : NORMAL0;
	float2 WspolrzedneTeksturowania : TEXCOORD0;
};

struct Dane_Wyjsciowe_VS
{
	float4 Pozycja : POSITION0;
	float4 Kolor : COLOR0;
	float2 WspolrzedneTeksturowania : TEXCOORD0;
	
	float4 Pozycja_Kopia : TEXCOORD1;
	float3 Normalna_Kopia : TEXCOORD2;
};

float4 OswietleniePhonga(float4 Pozycja,float4 Kolor,float4 Rozblysk,float3 N)
{
	float3 polozenieNaScenie = mul(Pozycja,World);
	float3 L = normalize(PozycjaZrodlaSwiatla - polozenieNaScenie);
	float dotLN = saturate(dot(L,N));

	float3 R = -L + 2*dotLN*N;
	float dotCR = saturate(pow(dot(R,KierunekDoKamery),ns));

	float4 _Wa = Wa;
	float4 _Wd = Wd;
	if(UzyjKoloruWerteksu) 
	{
		_Wa=Kolor;
		_Wd=Kolor;
	}
	float4 _Ws = Ws;
	if(UzyjMapyRozblysku)
	{
		_Ws = Rozblysk;
	}

	//if(input.Pozycja.x < 0) output.Kolor = float4(0,1,0,1);	
	float4 output_Kolor = saturate(_Wa*Ca);
	output_Kolor += saturate(_Wd*Cd*dotLN);
	output_Kolor += saturate(_Ws*Cs*dotCR);
	return output_Kolor;
}

Dane_Wyjsciowe_VS VS(Dane_Wejsciowe_VS input)
{
	Dane_Wyjsciowe_VS output;
	output.Pozycja = mul(input.Pozycja,WorldViewProjection);	
	output.WspolrzedneTeksturowania = input.WspolrzedneTeksturowania;
	
	output.Normalna_Kopia = mul(input.Normalna,World);

	if(!PreferujPerPixel) output.Kolor = OswietleniePhonga(input.Pozycja,input.Kolor,float4(1,1,1,1),output.Normalna_Kopia);
	else
	{
		if(UzyjKoloruWerteksu) output.Kolor = input.Kolor;
		else output.Kolor = Kolor;
	}
	output.Pozycja_Kopia = input.Pozycja;	

	return output;
}

float4 PS(Dane_Wyjsciowe_VS input) : COLOR0
{	
	float amplituda = 0.2;
	float czestosc = 10;
	float faza = 10*Czas;

	float4 kolorTekstury = tex2D(Probnik,input.WspolrzedneTeksturowania);
	float4 kolorTekstury2 = tex2D(Probnik2,input.WspolrzedneTeksturowania);
	float4 kolorMapyRozblysku = tex2D(ProbnikMapyRozblysku,input.WspolrzedneTeksturowania);
	
	//odcienie szarosci
	//float jasnosc = (kolorTekstury.x+kolorTekstury.y+kolorTekstury.z)/3;
	//kolorTekstury = float4(jasnosc,jasnosc,jasnosc,1);

	//mieszanie tekstur
	//kolorTekstury+=kolorTekstury2;
	//kolorTekstury/=2;
	//kolorTekstury*=kolorTekstury2;
	float waga1 = 1-sin(input.WspolrzedneTeksturowania.x*1.57);
	float waga2 = 1-waga1;
	kolorTekstury = waga1*kolorTekstury+waga2*kolorTekstury2;
	
	if(TeksturowanieWlaczone) input.Kolor*=kolorTekstury;

	if(!PreferujPerPixel) return input.Kolor;
	else return OswietleniePhonga(input.Pozycja_Kopia,input.Kolor,kolorMapyRozblysku,input.Normalna_Kopia);

		//if(input.Pozycja_Kopia.x < 0) return float4(0,1,0,1);
		//else return float4(0,1,1,1);
		//if(input.Pozycja_Kopia.x < amplituda*sin(czestosc*input.Pozycja_Kopia.y+faza)) return float4(0,1,0,1);
		//else return float4(0,1,1,1);
		//return float4(input.Normalna_Kopia.xyz,1);
}

Technique technika
{
	Pass przebieg
	{
		VertexShader = compile vs_2_0 VS();
		PixelShader = compile ps_2_0 PS();
	}
}